from setuptools import setup, find_packages

setup(
    name='mytestlib-AkioTest',
    version='1.0.0',
    url='http://dummy.org',
    author='Akio Shuto',
    author_email='syuto@vir.bekkoame.ne.jp',
    description='My Test Library.',
    packages=find_packages()
)
